@@ -17,6 +17,9 @@ GET = 0
 SET = 1
 POLL = 2
 
+GNSSLIST = {0: 'GPS', 1: 'SBAS', 2: 'Galileo', 3: 'BeiDou',
+            4: 'IMES', 5: 'QZSS', 6: 'GLONASS'}
+
 '''
 THESE ARE THE UBX PROTOCOL PAYLOAD ATTRIBUTE TYPES
 '''
